pub struct UrlEncodedForm<T, const LIMIT: usize = DEFAULT_URL_ENCODED_FORM_LIMIT>(pub T);Expand description
URL-encoded form extractor with const-generic payload size limit.
UrlEncodedForm is used to extract typed data from URL-encoded request payloads.
Extractor
To extract typed data from a request body, the inner type T must implement the
serde::Deserialize trait.
Use the LIMIT const generic parameter to control the payload size limit. The default limit
that is exported (DEFAULT_LIMIT) is 2MiB.
use actix_web::{post, App};
use actix_web_lab::extract::{UrlEncodedForm, DEFAULT_URL_ENCODED_FORM_LIMIT};
use serde::Deserialize;
#[derive(Deserialize)]
struct Info {
username: String,
}
/// Deserialize `Info` from request's body.
#[post("/")]
async fn index(info: UrlEncodedForm<Info>) -> String {
format!("Welcome {}!", info.username)
}
const LIMIT_32_MB: usize = 33_554_432;
/// Deserialize payload with a higher 32MiB limit.
#[post("/big-payload")]
async fn big_payload(info: UrlEncodedForm<Info, LIMIT_32_MB>) -> String {
format!("Welcome {}!", info.username)
}Tuple Fields
0: TImplementations
Sourceimpl<T, const LIMIT: usize> UrlEncodedForm<T, LIMIT>
impl<T, const LIMIT: usize> UrlEncodedForm<T, LIMIT>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Unwraps into inner T value.