pub struct Config {
pub bind_address: (String, u16),
pub database_url: Secret<String>,
pub auth_discovery_uri: Url,
pub client_id: String,
pub auth_token_uri: Url,
pub auth_admin_client_id: Option<String>,
pub auth_admin_client_secret: Option<Secret<String>>,
pub mode: Mode,
}Expand description
Configuration data for the server.
Fields
bind_address: (String, u16)The address and port the server should be started on.
database_url: Secret<String>The location of the database as a URL.
auth_discovery_uri: UrlThe discovery URI of the server that issues tokens.
Can be used to fetch other relevant URLs such as the jwks_uri or the token_endpoint.
client_id: StringThe client_id the frontend should use to log in its users.
auth_token_uri: UrlThe URI of the auth server used to acquire a token.
auth_admin_client_id: Option<String>The client_id the backend uses to communicate with the auth server.
auth_admin_client_secret: Option<Secret<String>>The client_secret the backend uses to communicate with the auth server.
mode: ModeThe mode of Access Control that is used.
Implementations