pub async fn fetch_keys(url: &str) -> JwkSetExpand description
Fetch jwks from the provided url and tries to parse them to [JwkSet].
Panics
- If the request to the auth server fails.
- If the keys cannot be deserialized to
JwkSetHelper.
pub async fn fetch_keys(url: &str) -> JwkSetFetch jwks from the provided url and tries to parse them to [JwkSet].
JwkSetHelper.