pub struct delete;Expand description
Endpoint for deleting Drawingss.
Errors
- If the connection to the database could not be established.
- If the current user does not have the appropriate permissions.