pub struct ConnectionPools {
pub fast_pool: Pool,
pub slow_pool: Pool,
}Expand description
Holds both connection pools.
Fields
fast_pool: Poolslow_pool: PoolMethods from Deref<Target = Pool>
pub async fn get(&self) -> Result<W, PoolError<<M as Manager>::Error>>
pub async fn get(&self) -> Result<W, PoolError<<M as Manager>::Error>>
Retrieves an [Object] from this [Pool] or waits for one to
become available.
Errors
See [PoolError] for details.
pub async fn timeout_get(
&self,
timeouts: &Timeouts,
) -> Result<W, PoolError<<M as Manager>::Error>>
pub async fn timeout_get( &self, timeouts: &Timeouts, ) -> Result<W, PoolError<<M as Manager>::Error>>
Retrieves an [Object] from this [Pool] using a different timeout
than the configured one.
Errors
See [PoolError] for details.
pub fn resize(&self, max_size: usize)
pub fn resize(&self, max_size: usize)
Resize the pool. This change the max_size of the pool dropping
excess objects and/or making space for new ones.
If the pool is closed this method does nothing. The [Pool::status] method
always reports a max_size of 0 for closed pools.
pub fn retain(
&self,
predicate: impl FnMut(&<M as Manager>::Type, Metrics) -> bool,
) -> RetainResult<<M as Manager>::Type>
pub fn retain( &self, predicate: impl FnMut(&<M as Manager>::Type, Metrics) -> bool, ) -> RetainResult<<M as Manager>::Type>
Retains only the objects specified by the given function.
This function is typically used to remove objects from the pool based on their current state or metrics.
Caution: This function blocks the entire pool while it is running. Therefore the given function should not block.
The following example starts a background task that runs every 30 seconds and removes objects from the pool that haven’t been used for more than one minute.
let interval = Duration::from_secs(30);
let max_age = Duration::from_secs(60);
tokio::spawn(async move {
loop {
tokio::time::sleep(interval).await;
pool.retain(|_, metrics| metrics.last_used() < max_age);
}
});pub fn timeouts(&self) -> Timeouts
pub fn timeouts(&self) -> Timeouts
Get current timeout configuration
pub fn close(&self)
pub fn close(&self)
Closes this [Pool].
All current and future tasks waiting for [Object]s will return
[PoolError::Closed] immediately.
This operation resizes the pool to 0.
pub fn status(&self) -> Status
pub fn status(&self) -> Status
Retrieves [Status] of this [Pool].
pub fn weak(&self) -> WeakPool<M>
pub fn weak(&self) -> WeakPool<M>
Returns a [WeakPool<T>] of this [Pool].