pub struct Api {
base_url: Url,
auth_data: Arc<Mutex<Option<AuthData>>>,
token_url: Url,
client_id: String,
client_secret: Secret<String>,
}Expand description
The keycloak admin API.
Fields
base_url: UrlBase url for the Keycloak admin REST API.
auth_data: Arc<Mutex<Option<AuthData>>>Cached access token (needs to be thread safe). Might be expired, in which case it will be refreshed.
token_url: UrlUrl for requesting the access token from the auth server.
client_id: StringThe client id for the oauth2 client.
client_secret: Secret<String>The client secret for the oauth2 client.
Implementations
Sourceimpl Api
impl Api
Sourceasync fn get<T: DeserializeOwned>(&self, client: &Client, url: Url) -> Result<T>
async fn get<T: DeserializeOwned>(&self, client: &Client, url: Url) -> Result<T>
Executes a get request authenticated with the access token.
Sourceasync fn get_or_refresh_access_token(
&self,
client: &Client,
) -> Result<Secret<String>>
async fn get_or_refresh_access_token( &self, client: &Client, ) -> Result<Secret<String>>
Gets the access token or refreshes it if it is expired.
Sourceasync fn refresh_access_token(&self, client: &Client) -> Result<AuthData>
async fn refresh_access_token(&self, client: &Client) -> Result<AuthData>
Refresh the access token.