pub struct HeatMapQueryParams {
pub plant_layer_id: Uuid,
pub shade_layer_id: Uuid,
pub hydrology_layer_id: Uuid,
pub soil_layer_id: Uuid,
pub plant_id: i32,
pub date: Option<NaiveDate>,
}Expand description
Query parameters to configure the generation of the heatmap.
Fields
plant_layer_id: UuidThe id of the plant layer the planting will be planted on.
shade_layer_id: UuidThe id of the shade layer the planting will be planted on.
hydrology_layer_id: UuidThe id of the hydrology layer the planting will be planted on.
soil_layer_id: UuidThe id of the soil layer the planting will be planted on.
plant_id: i32The id of the plant you want to plant.
date: Option<NaiveDate>The date at which to generate the heatmap.
Will be set to the current date if None.