pub struct NewMapDto {
pub name: String,
pub deletion_date: Option<NaiveDate>,
pub last_visit: Option<NaiveDate>,
pub is_inactive: bool,
pub zoom_factor: i16,
pub privacy: PrivacyAccessControl,
pub description: Option<String>,
pub location: Option<Coordinates>,
pub geometry: Polygon<Point>,
}Expand description
The information of a map necessary for its creation.
Fields
name: StringThe name of the map.
deletion_date: Option<NaiveDate>The date the map is supposed to be deleted.
last_visit: Option<NaiveDate>The date the last time the map view was opened by any user.
is_inactive: boolA flag indicating if this map is marked for deletion.
zoom_factor: i16The zoom factor of the map.
privacy: PrivacyAccessControlAn enum indicating if this map is private or not.
description: Option<String>The description of the map.
location: Option<Coordinates>The location of the map as a latitude/longitude point.
geometry: Polygon<Point>The geometry of the map.
E.g. {"rings": [[{"x": 0.0,"y": 0.0},{"x": 1000.0,"y": 0.0},{"x": 1000.0,"y": 1000.0},{"x": 0.0,"y": 1000.0},{"x": 0.0,"y": 0.0}]],"srid": 4326}