pub struct SeedSearchParameters {
pub name: Option<String>,
pub harvest_year: Option<i16>,
pub archived: Option<IncludeArchivedSeeds>,
}Expand description
Query parameters for searching seeds.
Fields
name: Option<String>Name of the seed to search for.
harvest_year: Option<i16>The exact harvest year of the seed.
archived: Option<IncludeArchivedSeeds>Whether archived, not archived or both kinds of seeds should be included.
If no value is provided, a default value of NotArchived is assumed.