pub struct Hydrology {
pub id: Uuid,
pub layer_id: Uuid,
pub water_requirement: WaterRequirementEnum,
pub geometry: Polygon<Point>,
pub add_date: Option<NaiveDate>,
pub remove_date: Option<NaiveDate>,
pub notes: String,
pub created_at: NaiveDateTime,
pub modified_at: NaiveDateTime,
pub created_by: Uuid,
pub modified_by: Uuid,
}Expand description
The Hydrology entity.
Fields
id: UuidThe id of the hydrology.
layer_id: UuidThe plant layer the hydrology is on.
water_requirement: WaterRequirementEnumThe water requirement.
geometry: Polygon<Point>The position of the hydrology on the map.
add_date: Option<NaiveDate>The date the hydrology was added to the map. If None, the hydrology always existed.
remove_date: Option<NaiveDate>The date the hydrology was removed from the map. If None, the hydrology is still on the map.
notes: StringMarkdown notes
created_at: NaiveDateTimeThe date the Shading was created.
modified_at: NaiveDateTimeThe date the Shading was modified.
created_by: UuidThe ID of the user who created the Shading.
modified_by: UuidThe ID of the user who last modified the Shading.