pub struct Shading {
pub id: Uuid,
pub layer_id: Uuid,
pub shade: Shade,
pub geometry: Polygon<Point>,
pub add_date: Option<NaiveDate>,
pub remove_date: Option<NaiveDate>,
pub notes: String,
pub created_at: NaiveDateTime,
pub modified_at: NaiveDateTime,
pub created_by: Uuid,
pub modified_by: Uuid,
}Expand description
The Shading entity.
Fields
id: UuidThe id of the shading.
layer_id: UuidThe plant layer the shadings is on.
shade: ShadeThe type/strength of shade.
geometry: Polygon<Point>The position of the shade on the map.
add_date: Option<NaiveDate>The date the shading was added to the map. If None, the shading always existed.
remove_date: Option<NaiveDate>The date the shading was removed from the map. If None, the shading is still on the map.
notes: StringMarkdown notes
created_at: NaiveDateTimeThe date the Shading was created.
modified_at: NaiveDateTimeThe date the Shading was modified.
created_by: UuidThe ID of the user who created the Shading.
modified_by: UuidThe ID of the user who last modified the Shading.