pub async fn get(pool: &SharedPool) -> Result<(), ServiceError>Expand description
Get the health status of the backend.
Errors
If the connection to the database could not be established.
pub async fn get(pool: &SharedPool) -> Result<(), ServiceError>Get the health status of the backend.
If the connection to the database could not be established.